@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+"""Define the line protocol test module."""
 
 from __future__ import absolute_import
 from __future__ import division
@@ -13,12 +14,15 @@ from influxdb import line_protocol
 
 
 class TestLineProtocol(unittest.TestCase):
+    """Define the LineProtocol test object."""
 
     def test_make_lines(self):
+        """Test make new lines in TestLineProtocol object."""
         data = {
             "tags": {
                 "empty_tag": "",
                 "none_tag": None,
+                "backslash_tag": "C:\\",
                 "integer_tag": 2,
                 "string_tag": "hello"
             },
@@ -38,11 +42,12 @@ class TestLineProtocol(unittest.TestCase):
 
         self.assertEqual(
             line_protocol.make_lines(data),
-            'test,integer_tag=2,string_tag=hello '
+            'test,backslash_tag=C:\\\\ ,integer_tag=2,string_tag=hello '
             'bool_val=True,float_val=1.1,int_val=1i,string_val="hello!"\n'
         )
 
     def test_timezone(self):
+        """Test timezone in TestLineProtocol object."""
         dt = datetime(2009, 11, 10, 23, 0, 0, 123456)
         utc = UTC.localize(dt)
         berlin = timezone('Europe/Berlin').localize(dt)
@@ -72,6 +77,7 @@ class TestLineProtocol(unittest.TestCase):
         )
 
     def test_string_val_newline(self):
+        """Test string value with newline in TestLineProtocol object."""
         data = {
             "points": [
                 {
@@ -89,6 +95,7 @@ class TestLineProtocol(unittest.TestCase):
         )
 
     def test_make_lines_unicode(self):
+        """Test make unicode lines in TestLineProtocol object."""
         data = {
             "tags": {
                 "unicode_tag": "\'Привет!\'"  # Hello! in Russian
@@ -108,13 +115,36 @@ class TestLineProtocol(unittest.TestCase):
             'test,unicode_tag=\'Привет!\' unicode_val="Привет!"\n'
         )
 
+    def test_tag_value_newline(self):
+        """Test make lines with tag value contains newline."""
+        data = {
+            "tags": {
+                "t1": "line1\nline2"
+            },
+            "points": [
+                {
+                    "measurement": "test",
+                    "fields": {
+                        "val": "hello"
+                    }
+                }
+            ]
+        }
+
+        self.assertEqual(
+            line_protocol.make_lines(data),
+            'test,t1=line1\\nline2 val="hello"\n'
+        )
+
     def test_quote_ident(self):
+        """Test quote indentation in TestLineProtocol object."""
         self.assertEqual(
             line_protocol.quote_ident(r"""\foo ' bar " Örf"""),
             r'''"\\foo ' bar \" Örf"'''
         )
 
     def test_quote_literal(self):
+        """Test quote literal in TestLineProtocol object."""
         self.assertEqual(
             line_protocol.quote_literal(r"""\foo ' bar " Örf"""),
             r"""'\\foo \' bar " Örf'"""
